django-thermostat
=================

Cronotherostat developed as a Django app. It belongs to the Python Home Automation Project


Django Home Automation is a set of Django apps which provides a REST API meant to
control home automation devices. It also provides a modular framework for
developing home automation drivers to enable more protocolos to be drived by this project.

It relies on the hautomation_restclient module to send domotic commands to the server

Further documentation found at http://jpardobl.com/home-automation-python-project/
